from django.utils.translation import pgettext_lazy

display_name = pgettext_lazy("theme switcher", "wide_container")

variables = {
    "container-sm": "768",
    "container-md": "991",
    "container-lg": "1200",
    "container-xl": "1600",
    "container-xxl": "1800",
}



from django.contrib.sites.models import Site
from django.core.cache import cache
from django.core.cache.utils import make_template_fragment_key
from django.db.models.signals import post_save
from django.dispatch import receiver
from django.utils.translation import get_language

from wagtail.signals import page_published, page_unpublished, post_page_move

from oscar.core.loading import get_model

OcyanSettings = get_model("ocyan_plugin_wagtail", "OcyanSettings")


def invalidate_key(key):
    cache.delete(make_template_fragment_key(key, vary_on=[get_language()]))
    cache.delete(make_template_fragment_key(key, vary_on=[get_language(), ""]))
    for site in Site.objects.all():
        cache.delete(make_template_fragment_key(key, vary_on=[get_language(), site]))


# pylint: disable=W0613
@receiver(post_page_move)
@receiver(page_unpublished)
@receiver(page_published)
def clear_header_page_menu(sender, **kwargs):
    invalidate_key("header_page_menu")


# pylint: disable=W0613
@receiver(post_save, sender=OcyanSettings)
def clear_footer_menu(sender, **kwargs):
    invalidate_key("footer_menu")


try:
    Category = get_model("catalogue", "Category")

    # pylint: disable=W0613
    @receiver(post_save, sender=Category)
    def clear_product_menu(sender, **kwargs):
        invalidate_key("header_product_menu")
        invalidate_key("header_mega_menu")

except (ImportError, LookupError):
    # no oscar in installed apps
    pass



from django.urls import include, path

from ocyan.core.fender import config
from ocyan.core.utils import merge_dicts
from ocyan.plugin.wagtail.block_plugin import BlockPluginConfig

from .sassfunctions import (
    ocyanbarenumber,
    ocyancolor,
    ocyanlist,
    ocyannumber,
    ocyanvariable,
)

OXYAN_SETTINGS = {
    "PASSWORD_REQUIRED_TEMPLATE": "oxyan/privacy/password_required.html",
    "WAGTAIL_FRONTEND_LOGIN_TEMPLATE": "oxyan/privacy/login_required.html",
    "OXYAN_THEME": config.get("themes", "theme", "default"),
    "OXYAN_THEME_MIXINS": config.get("themes", "mixins", []),
}


class OxyanThemesPluginConfig(BlockPluginConfig):
    def contribute_to_installed_apps(self, installed_apps):
        installed_apps.front.append("oxyan.themes")
        return installed_apps

    def contribute_to_sass_functions(self, sass_functions):
        return merge_dicts(
            sass_functions,
            {
                "ocyanvariable": ocyanvariable,
                "ocyanlist": ocyanlist,
                "ocyannumber": ocyannumber,
                "ocyanbarenumber": ocyanbarenumber,
                "ocyancolor": ocyancolor,
            },
        )

    def contribute_to_settings(self, settings):
        return merge_dicts(settings, OXYAN_SETTINGS, overwrite=True)

    def contribute_to_urlpatterns(self, urlpatterns):
        new_patterns = [
            path("themes/", include("oxyan.themes.urls")),
        ]
        new_patterns.extend(list(urlpatterns))
        return new_patterns

    def contribute_to_maintenance(self, maintenances):
        return maintenances + [
            ("remove_ocyan", "ocyan.plugin.themes.maintenance.remove_ocyan"),
        ]



from django.utils.translation import pgettext_lazy

display_name = pgettext_lazy("theme switcher", "page_above_header")

variables = {
    "order-logo": "2",
    "order-products": "3",
    "order-pages": "1",
    "order-search": "4",
    "order-user": "5",
    "order-basket": "6",
    "pagemenu-full-width": "true",
    "justify-search": "true",
}



from django.utils.translation import pgettext_lazy

from ocyan.core.fender import config

display_name = pgettext_lazy("theme switcher", "header_footer_contrast")
primary = config.get("themes", "primary")
headerBackground = config.get("themes", "header-background", primary)
footerBackground = config.get("themes", "footer-background", headerBackground)

headerColor = config.get("themes", "header-link-color", "#fff")
footerColor = config.get("themes", "footer-color", headerColor)

variables = {
    "header-background": headerBackground,
    "header-link-color": headerColor,
    "header-heading-color": headerColor,
    "footer-background": footerBackground,
    "basket-counter-background": "#ff6600",
    "footer-color": footerColor,
    "border-width": 0,
    "search-background": "#fff",
}



"""
This file defines the default values for all variables that can be altered
in specific templates
"""

from django.utils.translation import pgettext_lazy

from ocyan.core.fender import config

display_name = pgettext_lazy("theme switcher", "default")
primary = config.get("themes", "primary", "#0090e3")
basket_counter_background = config.get("themes", "basket-counter-background", primary)

variables = {
    # colors, try changing the white and black color and see what happens
    "primary": primary,
    "secondary": "#6c757d",
    "info": "#0dcaf0",
    "success": "#198754",
    "danger": "#dc3545",
    "warning": "#ffc107",
    "white": "#ffffff",
    "light": "#f8f9fa",
    "gray-100": "#f8f9fa",
    "gray-200": "#e9ecef",
    "gray-300": "#dee2e6",
    "gray-400": "#ced4da",
    "gray-500": "#adb5bd",
    "gray-600": "#6c757d",
    "gray-700": "#495057",
    "gray-800": "#343a40",
    "gray-900": "#212529",
    "black": "#000000",
    "price-color": "#212529",
    # Coyote variable
    "row-spacer": "3",
    # borders
    "border-width": 1,
    "border-radius-lg": 0,
    "border-radius": 0,
    "body-background": "#fff",
    "body-color": "#212529",
    # stefan weet dit setting
    "max-category-depth": 5,
    "image-min-height": 305,
    "thumbnail_geometry": "305x305",
    "footer-background": "#f8f9fa",
    "header-background": "#fff",
    "promo-background": "#fff",
    "no-padding-header": "false",
    "basket-counter-background": basket_counter_background,
    "search-background": "#e9ecef",
    "product-border-width": 0,
    "product-padding": 0,
    "product-shadow": "false",
    "product-rating": "true",
    "sticky_header": "false",
    "pagemenu-full-width": "false",
    "justify-search": "false",
    # no idea
    "order-logo": 1,
    "order-products": 2,
    "order-pages": 3,
    "order-search": 4,
    "order-user": 5,
    "order-basket": 6,
    # layout and spacing settings see https://getbootstrap.com/docs/5.0/layout/gutters/#change-the-gutters
    "spacer": 1,
    "grid-gutter-width": 1,
    "container-sm": 540,
    "container-md": 720,
    "container-lg": 960,
    "container-xl": 1140,
    "container-xxl": 1320,
    # font settings, zie https://getbootstrap.com/docs/5.0/content/typography/
    "font-size-root": 1,
    "font-family-base": "font-sans-serif",
    "font-size-base": 1,
    "line-height-base": 1.5,
    "font-weight-bold": 600,
    "font-weight-headers": 600,
    "headings-font-style": "normal",
    "header-font-family": [
        "system-ui",
        "-apple-system",
        '"Segoe UI"',
        "Roboto",
        '"Helvetica Neue"',
        "Arial",
        '"Noto Sans"',
        '"Liberation Sans"',
        "sans-serif",
        '"Apple Color Emoji"',
        '"Segoe UI Emoji"',
        '"Segoe UI Symbol"',
        '"Noto Color Emoji"',
    ],
    "font-family-sans-serif": [
        "system-ui",
        "-apple-system",
        '"Segoe UI"',
        "Roboto",
        '"Helvetica Neue"',
        "Arial",
        '"Noto Sans"',
        '"Liberation Sans"',
        "sans-serif",
        '"Apple Color Emoji"',
        '"Segoe UI Emoji"',
        '"Segoe UI Symbol"',
        '"Noto Color Emoji"',
    ],
    "font-family-monospace": [
        "SFMono-Regular",
        "Menlo",
        "Monaco",
        "Consolas",
        '"Liberation Mono"',
        '"Courier New"',
        "monospace",
    ],
}



import logging

from django import template

register = template.Library()

logger = logging.getLogger(__name__)


@register.filter(name="is_selected")
def value(tree_category, category):
    logger.error("Don't use ocyan_oscar templatetags, use oxyan instead")
    return category.path.startswith(tree_category.path[:-4])


@register.simple_tag
def rootimage(category):
    logger.error("Don't use ocyan_oscar templatetags, use oxyan instead")
    for cat in category.get_ancestors_and_self():
        if cat.image:
            return cat.image.url


@register.filter(name="startswith")
def startswith_tag(tree_category, category):
    logger.error("Don't use ocyan_oscar templatetags, use oxyan instead")
    return category.path.startswith(tree_category.path)



from unittest.mock import patch

from django.template import Context, Template
from django.test import RequestFactory, SimpleTestCase

from oxyan.themes.definitions import get_theme
from oxyan.themes.templatetags.oxyan import _render_optional_ai_assistant_widget


class OxyanThemesSmokeTests(SimpleTestCase):
    def test_theme_definition_loading(self):
        theme = get_theme("default")
        self.assertEqual(theme["primary_color"], theme["primary"])
        self.assertEqual(theme["secondary_color"], theme["secondary"])

    def test_optional_ai_assistant_widget_returns_empty_when_unavailable(self):
        request = RequestFactory().get("/")
        context = Context({"request": request})

        with patch(
            "oxyan.themes.templatetags.oxyan.import_module",
            side_effect=ImportError,
        ):
            self.assertEqual(_render_optional_ai_assistant_widget(context), "")

    def test_base_template_renders_without_ai_assistant_plugin(self):
        request = RequestFactory().get("/")
        template = Template(
            "{% load oxyan %}"
            "{% optional_ai_assistant_widget %}"
            "<div>base-smoke</div>"
        )

        with patch(
            "oxyan.themes.templatetags.oxyan.import_module",
            side_effect=ImportError,
        ):
            rendered = template.render(Context({"request": request}))

        self.assertIn("base-smoke", rendered)



from string import Template as StringTemplate
from unittest.mock import patch

import sass
from compressor.css import CssCompressor
from django.http import HttpResponse
from django.template import Context, Template
from django.utils.html import strip_tags
from django.views.decorators.cache import cache_page
from django_libsass import get_include_paths

from ocyan.core.plugins import get_sass_functions

from .definitions import get_theme

OXYAN_CSS_INCLUDE = StringTemplate(
    """{% load compress static %}{% compress css inline $theme_name %}<link rel="stylesheet" id="sass_$theme_name" type="text/x-scss" media="print" href="{% static 'scss/base.scss' %}">{% endcompress %}"""
)


@cache_page(60 * 15)
def preview_theme_css(request, theme_name):
    context = get_theme(theme_name)
    with patch("ocyan.plugin.themes.sassfunctions.definitions", context):
        tpl = Template(OXYAN_CSS_INCLUDE.substitute(theme_name=theme_name))
        css = tpl.render(Context())

    return HttpResponse(strip_tags(css), content_type="text/css")


@cache_page(60 * 15)
def preview_theme_css2(request, theme_name):
    context = get_theme(theme_name)
    with patch("ocyan.plugin.themes.sassfunctions.definitions", context):
        # pylint: disable=no-value-for-parameter
        a = CssCompressor()
        path = a.get_filename("scss/base.scss")
        css = sass.compile(
            filename=path,
            output_style="nested",
            source_comments=True,
            include_paths=get_include_paths(),
            custom_functions=get_sass_functions(),
        )

    return HttpResponse(css, content_type="text/css")



from django.utils.translation import pgettext_lazy

display_name = pgettext_lazy("theme switcher", "product_shadow")

variables = {
    "product-shadow": "true",
    "product-padding": "1",
    "product-rating": "false",
}



import subprocess
import sys


def remove_ocyan():
    return subprocess.check_output(
        [
            sys.executable,
            "-m",
            "pip",
            "uninstall",
            "ocyan.themes",
            "ocyan.plugin.themes",
            "--no-color",
            "--yes",
        ],
        stderr=subprocess.STDOUT,
    )



from django.utils.translation import gettext as _
from roadrunner.blocks import BaseStylingBlock

from wagtail import blocks
from wagtail.images.blocks import ImageChooserBlock


class PopupBlock(blocks.StructBlock):
    header = blocks.CharBlock(required=False)
    body = blocks.RichTextBlock(label=_("Body"), required=False)
    button_label = blocks.CharBlock(required=False)
    button_link = blocks.URLBlock(required=False)

    class Meta:
        label = "popup"
        icon = "duplicate"
        roadrunner_options = {"group": "extra"}
        group = "extra"


class ImageLinkBlock(blocks.StructBlock):
    image = ImageChooserBlock(required=False)
    link = blocks.CharBlock(required=False)

    class Meta:
        label = "imagelink"
        icon = "link"
        roadrunner_options = {"group": "extra"}
        group = "extra"


class BetterSliderBlock(blocks.StructBlock):
    image = ImageChooserBlock(required=False)
    body = blocks.RichTextBlock(required=False)
    position = blocks.ChoiceBlock(
        choices=[
            ("top-left", "Top left"),
            ("top-right", "Top right"),
            ("bottom-left", "Bottom left"),
            ("bottom-right", "Bottom right"),
            ("middle-left", "Middle left"),
            ("middle", "Middle"),
            ("middle-right", "Middle right"),
        ],
        required=False,
    )
    ribbon_color = blocks.CharBlock(required=False)
    ribbon_position = blocks.ChoiceBlock(
        choices=[("left", "Left"), ("right", "Right")], required=False
    )
    height = blocks.CharBlock(required=False)
    styling = BaseStylingBlock()


class BetterButtonBlock(blocks.StructBlock):
    label = blocks.CharBlock(required=False)
    url = blocks.CharBlock(required=False)
    classes = blocks.CharBlock(required=False)
    new_tab = blocks.BooleanBlock(
        required=False, default=False, label="Open in new tab"
    )

    class Meta:
        icon = "bold"
        label = "button x"
        roadrunner_options = {"group": "extra"}
        group = "extra"


def BetterSliderListBlock(**kwargs):
    kwargs.setdefault("template", "oxyan/blocks/better_slider.html")
    kwargs.setdefault("label", "slider x")
    kwargs.setdefault("icon", "strikethrough")
    kwargs.setdefault("roadrunner_options", {"group": "extra"})
    kwargs.setdefault("group", "extra")
    return blocks.ListBlock(BetterSliderBlock(), **kwargs)



from copy import deepcopy

from django.conf import settings
from django.utils.module_loading import import_string

from ocyan.core.fender import config

from oxyan.themes.definitions.default import variables as default_theme


def get_theme(name, mixins=()):
    _theme = deepcopy(default_theme)
    # read variables from the configured theme and prefer them over the default values
    configured_theme = import_string("oxyan.themes.definitions.%s.variables" % name)
    _theme.update(configured_theme)

    for _theme_name in mixins:
        _theme.update(
            import_string("oxyan.themes.definitions.%s.variables" % _theme_name)
        )

    # read variables from the project config and prefer them over the configured theme
    project_theme = config.get_section("themes") or {}
    _theme.update(project_theme)

    # Fallbacks for old theme color names
    _theme["primary_color"] = _theme["primary"]
    _theme["secondary_color"] = _theme["secondary"]
    _theme["info_color"] = _theme["info"]
    _theme["success_color"] = _theme["success"]
    _theme["danger_color"] = _theme["danger"]
    _theme["warning_color"] = _theme["warning"]
    return _theme


theme_name = settings.OXYAN_THEME
mixin_themes = settings.OXYAN_THEME_MIXINS

theme = get_theme(theme_name, mixin_themes)


def get_lazy_definitions():
    definitions_string = getattr(settings, "OXYAN_LAZY_THEME_DEFINITIONS", None)

    if definitions_string is None:
        return {}

    return import_string(definitions_string)()


def get(name, fallback=None):
    # update theme with lazy definitions
    theme.update(get_lazy_definitions())
    return theme.get(name, fallback)



# pylint: skip-file
from ocyan.core.fender import config

# pylint: disable=no-member
if "ocyan.plugin.wagtail" in config.ocyan_plugins:
    from django.utils.translation import gettext_lazy as _

    from wagtail.models import Page, PageManager
    from wagtail.query import PageQuerySet

    class BrowsablePageQueryset(PageQuerySet):
        def browsable(self):
            return self.live()

        def for_menu(self):
            return self.browsable()

    BrowsablePageManager = PageManager.from_queryset(BrowsablePageQueryset)

    class PageMenuProxy(Page):
        objects = BrowsablePageManager()
        _slug_separator = "/"

        is_creatable = False

        def get_full_slug(self, _=None):
            return self.specific.get_url(
                request=getattr(self.__class__, "_request", None),
                current_site=getattr(self.__class__, "_site", None),
            )

        @property
        def name(self):
            return self.title

        # pylint: disable=unused-argument
        def _get_absolute_url(self, parent_slug=None):
            return self.get_absolute_url()

        def get_absolute_url(self, _=None):
            return self.get_full_slug()

        def get_ancestors(self, inclusive=False):
            return self.__class__.objects.ancestor_of(self, inclusive).live().in_menu()

        def get_descendants(self, inclusive=False):
            return (
                self.__class__.objects.descendant_of(self, inclusive).live().in_menu()
            )

        def get_siblings(self, inclusive=True):
            return self.__class__.objects.sibling_of(self, inclusive).live().in_menu()

        @classmethod
        def from_page(cls, page, request=None, site=None):
            cls._request = request
            cls._site = site
            return cls.objects.get(pk=page.pk)

        class Meta(Page.Meta):
            proxy = True
            verbose_name = _("Empty page")
            verbose_name_plural = _("Empty pages")
            managed = False



# Generated by Django 2.2.13 on 2021-01-28 09:48

from django.db import migrations

from ocyan.core.fender import config
# pylint: disable=no-member
if "ocyan.plugin.wagtail" in config.ocyan_plugins:

    class Migration(migrations.Migration):

        initial = True

        dependencies = [
            ('wagtailcore', '0001_initial'),
        ]

        operations = [
            migrations.CreateModel(
                name='PageMenuProxy',
                fields=[
                ],
                options={
                    'verbose_name': 'Empty page',
                    'verbose_name_plural': 'Empty pages',
                    'abstract': False,
                    'managed': False,
                    'proxy': True,
                },
                bases=('wagtailcore.page',),
            ),
        ]
else:
    class Migration(migrations.Migration):
        initial = True
        options = []



from os.path import join, split, splitext
from importlib import import_module

from django import template
from django.template.loader import render_to_string
from django.utils.safestring import mark_safe

from ocyan.core.fender import config

from oxyan.themes import definitions

register = template.Library()


# pylint: disable=no-member
if "ocyan.plugin.wagtail" in config.ocyan_plugins:
    from wagtail.models import Site

    from oxyan.themes.models import PageMenuProxy

    @register.simple_tag(takes_context=True)
    def rootpage_as_category(context):
        request = context["request"]
        site = Site.find_for_request(request)
        root_page = site.root_page.specific.localized
        return PageMenuProxy.from_page(root_page, request=request, site=site)

    @register.simple_tag(takes_context=True)
    def main_navigation_pages(context):
        """Returns the pages to render in a menu in order."""
        request = context["request"]
        site = Site.find_for_request(request)
        root_page = site.root_page
        root_page_proxy = PageMenuProxy.from_page(root_page, request=request, site=site)
        pages = root_page_proxy.get_children().live().in_menu()
        return pages

else:

    @register.simple_tag
    def rootpage_as_category():
        return None

    @register.simple_tag
    def main_navigation_pages():
        return []


@register.filter(name="is_selected")
def value(tree_category, category):
    return category.path.startswith(tree_category.path[:-4])


@register.simple_tag
def rootimage(category):
    for cat in category.get_ancestors_and_self():
        if cat.image:
            return cat.image.url


@register.filter(name="startswith")
def startswith_tag(tree_category, category):
    return category.path.startswith(tree_category.path)


@register.simple_tag(takes_context=True)
def include_header(context, template_path):
    """
    select a header specific filename

    >>> include_header("partials/blaat/koe.html")
    "partials/blaat/header1.html"
    >>> include_header("partials/blaat/koe.css")
    "partials/blaat/header1.css"
    """
    path, basename = split(template_path)
    _, ext = splitext(basename)

    return render_to_string(
        join(path, "%s%s" % (definitions.get("header", "basic"), ext)),
        context=context.flatten(),
    )


@register.inclusion_tag(
    "templatetags/ocyan_wagtail/main_navigation.html", takes_context=True
)
def render_main_navigation_items(context, max_depth=999):
    """Renders the main navigation items"""
    pages = main_navigation_pages(context)
    current_page = context.get("page")
    current_path = getattr(current_page, "path", "") if current_page else ""

    def wrap(pages, current_depth=0):
        current_depth += 1
        for item in pages:
            if max_depth > current_depth:
                children = list(
                    wrap(item.get_children().live().in_menu(), current_depth)
                )
            else:
                children = []
            yield {
                "page": item,
                "is_active": current_path.startswith(item.path),
                "children": children,
            }

    return {"pages": list(wrap(pages)), "current_page": current_page}


@register.tag(name="captureas")
def do_captureas(parser, token):
    try:
        tag_name, args = token.contents.split(None, 1)  # pylint: disable=W0612
    except ValueError:
        raise template.TemplateSyntaxError("'captureas' node requires a variable name.")
    nodelist = parser.parse(("endcaptureas",))
    parser.delete_first_token()
    return CaptureasNode(nodelist, args)


class CaptureasNode(template.Node):
    def __init__(self, nodelist, varname):
        self.nodelist = nodelist
        self.varname = varname

    def render(self, context):
        output = self.nodelist.render(context)
        context[self.varname] = output
        return ""


@register.simple_tag
def get_oxyan_definition(name):
    return definitions.get(name)


def _render_optional_ai_assistant_widget(context):
    try:
        module = import_module(
            "ocyan.plugin.ai_assistant.templatetags.ai_assistant_tags"
        )
        widget_context = module.ai_assistant_widget(context)
    except Exception:
        return ""

    if not widget_context.get("render_widget"):
        return ""

    return render_to_string(
        "ai_assistant/includes/chat_widget.html",
        widget_context,
        request=context.get("request"),
    )


@register.simple_tag(takes_context=True)
def optional_ai_assistant_widget(context):
    return mark_safe(_render_optional_ai_assistant_widget(context))


@register.simple_tag(takes_context=True)
def get_pages(context, paginator, on_each_side):
    current_page = context["request"].GET.get("page", 1)
    pages = paginator.get_elided_page_range(
        current_page, on_each_side=on_each_side, on_ends=1
    )
    page_choices = ""

    for page in pages:
        # Elasticsearch gives an error when you have selected a product past 10k
        # so dont show the last page button when there are 10k or more products
        if page == paginator.num_pages and paginator.count >= 10000:
            continue
        extra_context = {}
        extra_context["page_number"] = page

        if page == paginator.ELLIPSIS:
            extra_context["ellipsis"] = True
        elif int(page) == int(current_page):
            extra_context["is_current_page"] = True

        page_choices = page_choices + render_to_string(
            "oscar/partials/page_link.html", context.flatten() | extra_context
        )

    return mark_safe(page_choices)



from django.urls import path

from .views import preview_theme_css

app_name = "themes"

urlpatterns = [
    path(
        "css/preview-<slug:theme_name>.css",
        view=preview_theme_css,
        name="preview-theme",
    ),
]



from django.utils.translation import pgettext_lazy

display_name = pgettext_lazy("theme switcher", "dark")

variables = {
    "white": "#1f2326",
    "gray-100": "#36393c",
    "gray-200": "#4b4f51",
    "gray-300": "#616466",
    "gray-400": "#787c7d",
    "gray-500": "#adb5bd",
    "gray-600": "#a6a7a8",
    "gray-700": "#bcbdbd",
    "gray-800": "#d3d3d4",
    "gray-900": "#e8e9e9",
    "body-background": "#1f2326",
    "body-color": "#fff",
    "header-background": "#25282b",
    "header-link-color": "#fff",
    "search-background": "#1f2326",
    "footer-background": "#25282b",
    "footer-color": "#fff",
    "promo-background": "#2f3236",
    "promo-color": "#fff",
    "price-color": "#fff",
    "light": "#36393c",
    "black": "#fff",
}



from django.utils.translation import pgettext_lazy

display_name = pgettext_lazy("theme switcher", "product_borders")

variables = {
    "border-radius": ".3",
    "product-border-width": "1",
    "product-padding": "1",
}



from django.utils.translation import pgettext_lazy

display_name = pgettext_lazy("theme switcher", "readability")

variables = {
    "font-size-root": 1.2,
    "header-font-family": ["serif"],
    "font-family-base": "font-family-sans-serif",
}



import subprocess
# pylint: disable=deprecated-module
from distutils.command import build as build_module
from setuptools import setup, find_packages


class BuildNPM(build_module.build):
    def run(self):
        subprocess.check_call(["npm", "install"])
        subprocess.check_call(["npm", "run", "build"])
        super().run()


test_requires = [
    "empty_testproject",
    "pylint-django",
    "isort",
    "ruff",
    "vdt.versionplugin.wheel",
    "ocyan.plugin.testing",
    "coverage",
]

PACKAGE_CLASSIFIERS = [
    "License :: Other/Proprietary License",
    "Framework :: Ocyan",
]

setup(
    name="oxyan.themes",
    version="2.0.1",
    url="https://git.mandelblog.com/mandel-plugins/oxyan.themes",
    author="Mandel",
    author_email="info@mandelblog.com",
    description="Ocyan application framework themes 2.0",
    packages=find_packages(exclude=["ez_setup", "sandbox", "tests"]),
    include_package_data=True,
    python_requires=">=3.6",
    install_requires=[
        "django",
        "django-oscar>2.0",
        "wagtail",
        "ocyan.plugin.wagtail",
        "ocyan.main",
        "django-compressor",
        "django-libsass",
        "sorl-thumbnail",
        "ocyan.plugin.seo",
    ],
    extras_require={
        "develop": {"wagtailfontawesome", "wagtailmenus", "wagtail-metadata"},
        "test": test_requires,
    },
    cmdclass={"build": BuildNPM},
    classifiers=PACKAGE_CLASSIFIERS,
)



from django.utils.translation import pgettext_lazy

display_name = pgettext_lazy("theme switcher", "carbasa")

variables = {
    "border-radius": 0.75,
    "row-spacer": "4",
    "font-weight-normal": 100,
    "font-weight-bold": 800,
    "font-weight-headers": 400,
}



import sass
from PIL import ImageColor


def hex2sassColor(color):
    try:
        color = ImageColor.getrgb(color)
        # No alpha is given
        if len(color) == 3:
            return sass.SassColor(*color, a=1)
        return sass.SassColor(*color)
    except ValueError:
        raise ValueError("hex2rgba can only parse hex colors.")


def ocyanvariable(variable):
    from oxyan.themes import definitions

    return definitions.get(variable)


def ocyanlist(name):
    from oxyan.themes import definitions

    _list = definitions.get(name, [])
    return sass.SassList(_list, sass.SASS_SEPARATOR_COMMA, False)


def ocyannumber(name, unit):
    from oxyan.themes import definitions

    number = definitions.get(name)
    return sass.SassNumber(number, unit)


def ocyanbarenumber(name):
    return ocyannumber(name, "")


def ocyancolor(name):
    from oxyan.themes import definitions

    color = definitions.get(name)
    return hex2sassColor(color)
